@@ -10,7 +10,7 @@
 #include <functional>
 #include <RcppArmadillo.h>
 #include "cts.h"
-#include "templates.h"
+#include "Rfast2/templates.h"
 
 // [[Rcpp::plugins("cpp11")]]
 // [[Rcpp::depends("RcppArmadillo")]]
