@@ -3,7 +3,7 @@
 #include <RcppArmadillo.h>
 #include "reg_lib2.h"
 #include <vector>
-#include "templates.h"
+#include "Rfast2/templates.h"
 #include "reg_lib_helper.h"
 #include "mn.h"
 #include "apply_funcs_templates.h"
